@@ -1,7 +1,7 @@
 package Perinci::Result::Format::Lite;
 
-our $DATE = '2016-01-19'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-03-09'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -28,7 +28,7 @@ sub firstidx (&@) {
 
 sub _json {
     state $json = do {
-        if    (eval { require JSON::XS; 1 })   { JSON::XS->new->canonical(1)->allow_nonref }
+        if    (eval { require Cpanel::JSON::XS; 1 })   { Cpanel::JSON::XS->new->canonical(1)->allow_nonref }
         elsif (eval { require JSON::Tiny::Subclassable; 1 }) { JSON::Tiny::Subclassable->new }
         elsif (eval { require JSON::PP; 1 })   { JSON::PP->new->canonical(1)->allow_nonref }
         else { die "Can't find any JSON module" }
@@ -255,7 +255,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.12 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-01-19.
+This document describes version 0.13 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2016-03-09.
 
 =head1 SYNOPSIS
 
